<?php
/**
 * BlogSlog Pro: Color Patterns
 *
 * @package WordPress
 * @subpackage BlogSlog Pro
 * @since 1.0
 */

/**
 * Generate the CSS for the current custom color scheme.
 */
function blogslog_pro_custom_colors_css() {
  	$options= blogslog_pro_get_theme_options();

	$color_value = $options['colorscheme_hue'];
	
	$css = '
	/*--------------------------------------------------------------
	# Background Color
	--------------------------------------------------------------*/
	.backtotop,
	#respond input[type="submit"],
	.pagination .page-numbers.current,
	.pagination .page-numbers:hover,
	.pagination .page-numbers:focus,
	.widget_search form.search-form .search-submit:hover,
	.widget_search form.search-form .search-submit:focus,
	input[type="submit"],
	.jetpack_subscription_widget input[type="submit"],
	.jetpack_subscription_widget input[type="submit"]:hover,
	.jetpack_subscription_widget input[type="submit"]:focus,
	#secondary .jetpack_subscription_widget input[type="submit"]:hover,
	#secondary .jetpack_subscription_widget input[type="submit"]:focus,
	.reply a,
	.btn,
	.blog-posts .entry-meta:before,
	.single .posted-on a {
	    background-color: ' . esc_attr($color_value) . ';
	}

	/*--------------------------------------------------------------
	# Text Color
	--------------------------------------------------------------*/
	a,
	.main-navigation ul#primary-menu li.current-menu-item > a,
	.main-navigation ul#primary-menu li:hover > a,
	.post-navigation a:hover, 
	.posts-navigation a:hover,
	.post-navigation a:focus, 
	.posts-navigation a:focus,
	.widget_popular_post h3 a:hover,
	.widget_popular_post h3 a:focus,
	.widget_popular_post a:hover time,
	.widget_popular_post a:focus time,
	.widget_latest_post h3 a:hover,
	.widget_latest_post h3 a:focus,
	.widget_latest_post a:hover time,
	.widget_latest_post a:focus time,
	.widget_featured_post h3 a:hover,
	.widget_featured_post h3 a:focus,
	.widget_featured_post a:hover time,
	.widget_featured_post a:focus time,
	.widget_popular_post a time,
	.widget_popular_post time,
	.widget_latest_post a time,
	.widget_latest_post time,
	.widget_featured_post a time,
	.widget_featured_post time,
	#secondary a:hover,
	#secondary a:focus,
	ul.post-categories li:after,
	.byline span a:hover,
	.byline span a:focus,
	.posted-on a:hover,
	.posted-on a:focus,
	.comment-meta .url:hover,
	.comment-meta .url:focus,
	.comment-metadata a,
	.comment-metadata a time,
	.comment-metadata a:hover,
	.comment-metadata a:focus,
	.comment-metadata a:hover time,
	.comment-metadata a:focus time,
	.section-subtitle,
	.more-link:hover,
	.more-link:focus,
	.blog-posts .entry-title a:hover,
	.blog-posts .entry-title a:focus,
	#colophon .cat-links a,
	#colophon .footer-widgets-area ul li a:hover,
	#colophon .footer-widgets-area ul li a:focus {
		color: ' . esc_attr($color_value) . ';
	}

	.loader-container svg,
	.main-navigation ul#primary-menu li:hover > svg,
	.main-navigation li.menu-item-has-children:hover > a > svg,
	.main-navigation li.menu-item-has-children > a:hover > svg,
	.main-navigation ul#primary-menu > li.current-menu-item > a > svg,
	.main-navigation ul.nav-menu > li > a.search:hover svg.icon-search,
	.main-navigation ul.nav-menu > li > a.search:focus svg.icon-search,
	.main-navigation li.search-menu a:hover svg,
	.main-navigation li.search-menu a:focus svg,
	.main-navigation li.search-menu a.search-active svg,
	.main-navigation a:hover,
	.main-navigation ul.nav-menu > li > a:hover,
	.widget svg,
	.navigation.posts-navigation a:hover svg, 
	.navigation.post-navigation a:hover svg,
	.navigation.posts-navigation a:focus svg, 
	.navigation.post-navigation a:focus svg,
	.search-submit:hover svg, 
	#featured-introduction-section .entry-container .search-submit:hover svg.icon-search {
		fill: ' . esc_attr($color_value) . ';
	}

	/*--------------------------------------------------------------
	# Border Color
	--------------------------------------------------------------*/
	.more-link:after {
	    border-left-color: ' . esc_attr($color_value) . ';
	}

	/*--------------------------------------------------------------
	# Responsive Color
	--------------------------------------------------------------*/
	@media screen and (min-width: 1024px) {
		#masthead .main-navigation ul#primary-menu li.current-menu-item > a,
		#masthead .main-navigation ul.nav-menu > li > a:hover,
		.main-navigation ul#primary-menu li:hover > a,
		#secondary-navigation .main-navigation ul.nav-menu > li.current-menu-item > a,
		#secondary-navigation .main-navigation ul.nav-menu > li > a:hover,
		#secondary-navigation .main-navigation ul.nav-menu > li:hover > a {
			color: ' . esc_attr($color_value) . ';
		}
		.main-navigation ul#primary-menu > li.current-menu-item > a > svg,
		#secondary-navigation .main-navigation ul.nav-menu > li.current-menu-item > a svg,
		#secondary-navigation .main-navigation ul.nav-menu > li > a:hover svg,
		#secondary-navigation .main-navigation ul.nav-menu > li:hover > a svg {
			fill: ' . esc_attr($color_value) . ';
		}
		.main-navigation ul.sub-menu li:hover > a,
		.main-navigation ul.sub-menu li:focus > a {
			background-color: ' . esc_attr($color_value) . ';
			color: #fff;
		}
	}';

	$css .= '
	@keyframes preloader {
	    0% {height:5px;transform:translateY(0px);background: ' . esc_attr($color_value) . ';}
	    25% {height:30px;transform:translateY(15px);background: ' . esc_attr($color_value) . ';}
	    50% {height:5px;transform:translateY(0px);background: ' . esc_attr($color_value) . ';}
	    100% {height:5px;transform:translateY(0px);background: ' . esc_attr($color_value) . ';}
	}';

	/**
	 * Filters BlogSlog Pro custom colors CSS.
	 *
	 * @since BlogSlog Pro 1.0.0
	 *
	 * @param string $css        Base theme colors CSS.
	 */
	return apply_filters( 'blogslog_pro_custom_colors_css', $css );
}
