<?php
/**
 * Banner Section options
 *
 * @package Theme Palace
 * @subpackage BlogSlog Pro
 * @since BlogSlog Pro 1.0.0
 */

// Add Banner section
$wp_customize->add_section( 'blogslog_pro_banner_section', array(
	'title'             => esc_html__( 'Banner','blogslog-pro' ),
	'description'       => esc_html__( 'Banner Section options.', 'blogslog-pro' ),
	'panel'             => 'blogslog_pro_front_page_panel',
) );

// Banner content enable control and setting
$wp_customize->add_setting( 'blogslog_pro_theme_options[banner_section_enable]', array(
	'default'			=> 	$options['banner_section_enable'],
	'sanitize_callback' => 'blogslog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new BlogSlog_Pro_Switch_Control( $wp_customize, 'blogslog_pro_theme_options[banner_section_enable]', array(
	'label'             => esc_html__( 'Banner Section Enable', 'blogslog-pro' ),
	'section'           => 'blogslog_pro_banner_section',
	'on_off_label' 		=> blogslog_pro_switch_options(),
) ) );

// Banner content enable control and setting
$wp_customize->add_setting( 'blogslog_pro_theme_options[banner_search_enable]', array(
	'default'			=> 	$options['banner_search_enable'],
	'sanitize_callback' => 'blogslog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new BlogSlog_Pro_Switch_Control( $wp_customize, 'blogslog_pro_theme_options[banner_search_enable]', array(
	'label'             => esc_html__( 'Search Enable', 'blogslog-pro' ),
	'section'           => 'blogslog_pro_banner_section',
	'active_callback' 	=> 'blogslog_pro_is_banner_section_enable',
	'on_off_label' 		=> blogslog_pro_switch_options(),
) ) );

// Banner content type control and setting
$wp_customize->add_setting( 'blogslog_pro_theme_options[banner_content_type]', array(
	'default'          	=> $options['banner_content_type'],
	'sanitize_callback' => 'blogslog_pro_sanitize_select',
) );

$wp_customize->add_control( 'blogslog_pro_theme_options[banner_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'blogslog-pro' ),
	'section'           => 'blogslog_pro_banner_section',
	'type'				=> 'select',
	'active_callback' 	=> 'blogslog_pro_is_banner_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'blogslog-pro' ),
		'post' 		=> esc_html__( 'Post', 'blogslog-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'blogslog-pro' ),
	),
) );

// banner pages drop down chooser control and setting
$wp_customize->add_setting( 'blogslog_pro_theme_options[banner_content_page]', array(
	'sanitize_callback' => 'blogslog_pro_sanitize_page',
) );

$wp_customize->add_control( new BlogSlog_Pro_Dropdown_Chooser( $wp_customize, 'blogslog_pro_theme_options[banner_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'blogslog-pro' ),
	'section'           => 'blogslog_pro_banner_section',
	'choices'			=> blogslog_pro_page_choices(),
	'active_callback'	=> 'blogslog_pro_is_banner_section_content_page_enable',
) ) );

// banner posts drop down chooser control and setting
$wp_customize->add_setting( 'blogslog_pro_theme_options[banner_content_post]', array(
	'sanitize_callback' => 'blogslog_pro_sanitize_page',
) );

$wp_customize->add_control( new BlogSlog_Pro_Dropdown_Chooser( $wp_customize, 'blogslog_pro_theme_options[banner_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'blogslog-pro' ),
	'section'           => 'blogslog_pro_banner_section',
	'choices'			=> blogslog_pro_post_choices(),
	'active_callback'	=> 'blogslog_pro_is_banner_section_content_post_enable',
) ) );

// banner title setting and control
$wp_customize->add_setting( 'blogslog_pro_theme_options[banner_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['banner_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'blogslog_pro_theme_options[banner_title]', array(
	'label'           	=> esc_html__( 'Title', 'blogslog-pro' ),
	'section'        	=> 'blogslog_pro_banner_section',
	'active_callback' 	=> 'blogslog_pro_is_banner_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'blogslog_pro_theme_options[banner_title]', array(
		'selector'            => '#featured-introduction-section .entry-header h2.entry-title a',
		'settings'            => 'blogslog_pro_theme_options[banner_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'blogslog_pro_banner_title_partial',
    ) );
}

// banner url setting and control
$wp_customize->add_setting( 'blogslog_pro_theme_options[banner_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'blogslog_pro_theme_options[banner_link]', array(
	'label'           	=> esc_html__( 'Link', 'blogslog-pro' ),
	'section'        	=> 'blogslog_pro_banner_section',
	'active_callback' 	=> 'blogslog_pro_is_banner_section_content_custom_enable',
	'type'				=> 'url',
) );

// banner image setting and control.
$wp_customize->add_setting( 'blogslog_pro_theme_options[banner_image]', array(
	'sanitize_callback' => 'blogslog_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'blogslog_pro_theme_options[banner_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'blogslog-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'blogslog-pro' ), 1920, 1080 ),
		'section'     		=> 'blogslog_pro_banner_section',
		'active_callback'	=> 'blogslog_pro_is_banner_section_content_custom_enable',
) ) );

// banner posts drop down chooser control and setting
$wp_customize->add_setting( 'blogslog_pro_theme_options[banner_categories]', array(
	'sanitize_callback' => 'blogslog_pro_sanitize_category_list',
) );

$wp_customize->add_control( new BlogSlog_Pro_Dropdown_Category_Control( $wp_customize, 'blogslog_pro_theme_options[banner_categories]', array(
	'label'             => esc_html__( 'Select Categories', 'blogslog-pro' ),
	'description'       => esc_html__( 'Note: Press CTRL and select multiple categories for quick links.', 'blogslog-pro' ),
	'type'           	=> 'dropdown-categories',
	'section'           => 'blogslog_pro_banner_section',
	'active_callback'	=> 'blogslog_pro_is_banner_section_enable',
) ) );
