<?php
/**
 * Featured section
 *
 * This is the template for the content of featured section
 *
 * @package Theme Palace
 * @subpackage BlogSlog Pro
 * @since BlogSlog Pro 1.0.0
 */
if ( ! function_exists( 'blogslog_pro_add_featured_section' ) ) :
    /**
    * Add featured section
    *
    *@since BlogSlog Pro 1.0.0
    */
    function blogslog_pro_add_featured_section() {
    	$options = blogslog_pro_get_theme_options();
        // Check if featured is enabled on frontpage
        $featured_enable = apply_filters( 'blogslog_pro_section_status', true, 'featured_section_enable' );

        if ( true !== $featured_enable ) {
            return false;
        }
        // Get featured section details
        $section_details = array();
        $section_details = apply_filters( 'blogslog_pro_filter_featured_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured section now.
        blogslog_pro_render_featured_section( $section_details );
    }
endif;

if ( ! function_exists( 'blogslog_pro_get_featured_section_details' ) ) :
    /**
    * featured section details.
    *
    * @since BlogSlog Pro 1.0.0
    * @param array $input featured section details.
    */
    function blogslog_pro_get_featured_section_details( $input ) {
        $options = blogslog_pro_get_theme_options();

        // Content type.
        $featured_content_type  = $options['featured_content_type'];
        $featured_count = ! empty( $options['featured_count'] ) ? $options['featured_count'] : 4;
        
        $content = array();
        switch ( $featured_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $featured_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_content_category'] ) ? $options['featured_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $featured_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = blogslog_pro_trim_content( 25 );
                    $page_post['author']    = blogslog_pro_author();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured section content details.
add_filter( 'blogslog_pro_filter_featured_section_details', 'blogslog_pro_get_featured_section_details' );


if ( ! function_exists( 'blogslog_pro_render_featured_section' ) ) :
  /**
   * Start featured section
   *
   * @return string featured content
   * @since BlogSlog Pro 1.0.0
   *
   */
   function blogslog_pro_render_featured_section( $content_details = array() ) {
        $options = blogslog_pro_get_theme_options();
        $featured_content_type  = $options['featured_content_type'];
        $featured_layout = ! empty( $options['featured_layout'] ) ? $options['featured_layout'] : 'featured-modern';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="featured-posts" class="relative page-section blog-posts <?php echo esc_attr( $featured_layout ); ?>">
            <?php if ( ! empty( $options['featured_title'] ) ) : ?>
                <div class="section-header wrapper">
                    <h2 class="section-title"><?php echo esc_html( $options['featured_title'] ); ?></h2>
                    <?php if ( ! empty( $options['featured_btn_title'] ) && ! empty( $options['featured_btn_url'] ) ) : ?>
                        <a href="<?php echo esc_url( $options['featured_btn_url'] ); ?>" class="more-link"><?php echo esc_html( $options['featured_btn_title'] ); ?></a>
                    <?php endif; ?>
                </div><!-- .section-header -->
            <?php endif; ?>

            <div class="wrapper">
                <div class="posts-slider" data-slick='{"slidesToShow": 5, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": true, "draggable": true, "fade": false, "centerMode": true }'>
                    <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <?php if ( 'page' !== $featured_content_type ) : ?>
                                    <span class="cat-links">
                                        <?php the_category( '', '', $content['id'] ); ?>
                                    </span><!-- .cat-links -->
                                <?php endif; ?>

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->

                                <?php if ( 'page' !== $featured_content_type ) : ?>
                                    <div class="entry-meta">
                                        <?php 
                                            blogslog_pro_posted_on( $content['id'] ); 
                                            echo wp_kses_post( $content['author'] );
                                        ?> 
                                    </div><!-- .entry-meta -->
                                <?php endif; ?>
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .posts-slider -->
            </div><!-- .wrapper -->

            <?php if ( ! empty( $options['featured_btn_title'] ) && ! empty( $options['featured_btn_url'] ) ) : ?>
                <div class="section-header view-more">
                    <a href="<?php echo esc_url( $options['featured_btn_url'] ); ?>" class="more-link"><?php echo esc_html( $options['featured_btn_title'] ); ?></a>
                </div><!-- .view-more -->
            <?php endif; ?>
        </div><!-- #featured-posts -->        
    <?php }
endif;